@@ -1,6 +1,8 @@
 import sys
 import re
 
+print("Code is running...")
+
 def get_path():
     frame = sys._getframe()
     while frame.f_back:
@@ -25,7 +27,11 @@ def run(exit=0):
     path = get_path()
 
     with open(path, "r") as file:
-        code = file.read()
+        try:
+            code = file.read()
+
+        except FileNotFoundError:
+            raise FileNotFoundError("File: '"+path+"' could not be found.")
 
         try:
             match = re.search(r"""(?:[^"\']|^)import\s+arrowpython(?:[^"\']|$)""", code)
@@ -35,6 +41,7 @@ def run(exit=0):
             raise SyntaxError('Could not find import statement. Try putting "import arrowpython" on the first line.')
 
         code = transpile(code)
+        print(code)
 
     exec(code)
 
